translate.convert.po2txt.po2txt

Package translate :: Package convert :: Module po2txt :: Class po2txt |
[hide private]
[frames] | no frames]

# Class po2txt

source code

po2txt can take a po file and generate txt. best to give it a template file otherwise will just concat msgstrs

Instance Methods | [hide private]
__init__(self, wrap=None) | source code
wrapmessage(self, message) rewraps text as required | source code
convertstore(self, inputstore, includefuzzy) converts a file to txt format | source code
mergestore(self, inputstore, templatetext, includefuzzy) converts a file to txt format | source code